@@ -5,7 +5,7 @@
  *                                                                         *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2014 Insecure.Com LLC. Nmap is    *
+ * The Nmap Security Scanner is (C) 1996-2015 Insecure.Com LLC. Nmap is    *
  * also a registered trademark of Insecure.Com LLC.  This program is free  *
  * software; you may redistribute and/or modify it under the terms of the  *
  * GNU General Public License as published by the Free Software            *
@@ -96,8 +96,7 @@
  *                                                                         *
  * Source is provided to this software because we believe users have a     *
  * right to know exactly what a program is going to do before they run it. *
- * This also allows you to audit the software for security holes (none     *
- * have been found so far).                                                *
+ * This also allows you to audit the software for security holes.          *
  *                                                                         *
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
@@ -118,11 +117,11 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of              *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
  * license file for more details (it's in a COPYING file included with     *
- * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
+ * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: FingerPrintResults.cc 33540 2014-08-16 02:45:47Z dmiller $ */
+/* $Id: FingerPrintResults.cc 34574 2015-06-03 13:01:29Z dmiller $ */
 
 #include "FingerPrintResults.h"
 #include "osscan.h"
@@ -138,7 +137,9 @@ FingerPrintResults::FingerPrintResults() {
   osscan_opentcpport = osscan_closedtcpport = osscan_closedudpport = -1;
   distance = -1;
   distance_guess = -1;
+  distance_calculation_method = DIST_METHOD_NONE;
   maxTimingRatio = 0;
+  incomplete = false;
 }
 
 FingerPrintResults::~FingerPrintResults() {
@@ -234,6 +235,10 @@ const char *FingerPrintResults::OmitSubmissionFP() {
     return "Didn't receive UDP response. Please try again with -sSU";
   }
 
+  if (incomplete) {
+    return "Some probes failed to send so results incomplete";
+  }
+
   return NULL;
 }
 
@@ -247,6 +252,10 @@ const char *FingerPrintResultsIPv6::OmitSubmissionFP() {
     return reason;
   }
 
+  if (incomplete) {
+    return "Some probes failed to send so results incomplete";
+  }
+
   return NULL;
 }
 
@@ -330,4 +339,3 @@ bool FingerPrintResults::classAlreadyExistsInResults(struct OS_Classification *O
   // Went through all the results -- no duplicates found
   return false;
 }
-
