@@ -6,7 +6,7 @@
  *                                                                         *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2014 Insecure.Com LLC. Nmap is    *
+ * The Nmap Security Scanner is (C) 1996-2015 Insecure.Com LLC. Nmap is    *
  * also a registered trademark of Insecure.Com LLC.  This program is free  *
  * software; you may redistribute and/or modify it under the terms of the  *
  * GNU General Public License as published by the Free Software            *
@@ -97,8 +97,7 @@
  *                                                                         *
  * Source is provided to this software because we believe users have a     *
  * right to know exactly what a program is going to do before they run it. *
- * This also allows you to audit the software for security holes (none     *
- * have been found so far).                                                *
+ * This also allows you to audit the software for security holes.          *
  *                                                                         *
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
@@ -119,17 +118,18 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of              *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
  * license file for more details (it's in a COPYING file included with     *
- * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
+ * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: Target.cc 33540 2014-08-16 02:45:47Z dmiller $ */
+/* $Id: Target.cc 34798 2015-06-30 04:04:51Z dmiller $ */
 
 #ifdef WIN32
 #include "nmap_winconfig.h"
 #endif
 
 #include "Target.h"
+#include "FingerPrintResults.h" /* for ~FingerPrintResults() */
 #include <dnet.h>
 #include "nbase.h"
 #include "NmapOps.h"
@@ -517,7 +517,7 @@ bool Target::timedOut(const struct timeval *now) {
     used += TIMEVAL_MSEC_SUBTRACT(tv, htn.toclock_start);
   }
 
-  return (used > o.host_timeout)? true : false;
+  return (used > o.host_timeout);
 }
 
 
@@ -575,5 +575,3 @@ void Target::osscanSetFlag(int flag) {
         else
                 osscan_flag = flag;
 }
-
-
