@@ -6,7 +6,7 @@
  *                                                                         *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2014 Insecure.Com LLC. Nmap is    *
+ * The Nmap Security Scanner is (C) 1996-2015 Insecure.Com LLC. Nmap is    *
  * also a registered trademark of Insecure.Com LLC.  This program is free  *
  * software; you may redistribute and/or modify it under the terms of the  *
  * GNU General Public License as published by the Free Software            *
@@ -97,8 +97,7 @@
  *                                                                         *
  * Source is provided to this software because we believe users have a     *
  * right to know exactly what a program is going to do before they run it. *
- * This also allows you to audit the software for security holes (none     *
- * have been found so far).                                                *
+ * This also allows you to audit the software for security holes.          *
  *                                                                         *
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
@@ -119,17 +118,17 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of              *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
  * license file for more details (it's in a COPYING file included with     *
- * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
+ * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: Target.h 33540 2014-08-16 02:45:47Z dmiller $ */
+/* $Id: Target.h 34816 2015-07-02 04:14:51Z dmiller $ */
 
 #ifndef TARGET_H
 #define TARGET_H
 
-#include "nmap.h"
-#include "FingerPrintResults.h"
+#include "nbase.h"
+
 #include "libnetutil/netutil.h"
 
 #ifndef NOLUA
@@ -138,8 +137,10 @@
 
 #include "portreasons.h"
 #include "portlist.h"
-#include "tcpip.h"
 #include "scan_engine.h"
+#include "osscan.h"
+#include "osscan2.h"
+class FingerPrintResults;
 
 #include <list>
 #include <string>
@@ -152,16 +153,6 @@ enum osscan_flags {
         OS_NOTPERF=0, OS_PERF, OS_PERF_UNREL
 };
 
-/* The method used to calculate the Target::distance, included in OS
-   fingerprints. */
-enum dist_calc_method {
-        DIST_METHOD_NONE,
-        DIST_METHOD_LOCALHOST,
-        DIST_METHOD_DIRECT,
-        DIST_METHOD_ICMP,
-        DIST_METHOD_TRACEROUTE
-};
-
 struct host_timeout_nfo {
   unsigned long msecs_used; /* How many msecs has this Target used? */
   bool toclock_running; /* Is the clock running right now? */
@@ -186,7 +177,7 @@ struct TracerouteHop {
 };
 
 class Target {
- public: /* For now ... a lot of the data members should be made private */
+ public: /* For now ... TODO: a lot of the data members should be made private */
   Target();
   ~Target();
   /* Recycles the object by freeing internal objects and reinitializing
@@ -375,3 +366,4 @@ class Target {
 };
 
 #endif /* TARGET_H */
+
