@@ -2,7 +2,7 @@
  * ncat_core.h                                                             *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2014 Insecure.Com LLC. Nmap is    *
+ * The Nmap Security Scanner is (C) 1996-2015 Insecure.Com LLC. Nmap is    *
  * also a registered trademark of Insecure.Com LLC.  This program is free  *
  * software; you may redistribute and/or modify it under the terms of the  *
  * GNU General Public License as published by the Free Software            *
@@ -93,8 +93,7 @@
  *                                                                         *
  * Source is provided to this software because we believe users have a     *
  * right to know exactly what a program is going to do before they run it. *
- * This also allows you to audit the software for security holes (none     *
- * have been found so far).                                                *
+ * This also allows you to audit the software for security holes.          *
  *                                                                         *
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
@@ -115,11 +114,14 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of              *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
  * license file for more details (it's in a COPYING file included with     *
- * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
+ * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: ncat_core.h 33540 2014-08-16 02:45:47Z dmiller $ */
+/* $Id: ncat_core.h 35432 2015-11-15 14:08:02Z dmiller $ */
+
+#ifndef NCAT_CORE_H
+#define NCAT_CORE_H
 
 #include "nsock.h"
 #include "nbase.h"
@@ -159,6 +161,7 @@ struct options {
     int keepopen;
     int sendonly;
     int recvonly;
+    int noshutdown;
     int telnet;
     int linedelay;
     int chat;
@@ -201,6 +204,7 @@ struct options {
     char *sslkey;
     int sslverify;
     char *ssltrustfile;
+    char *sslciphers;
 };
 
 extern struct options o;
@@ -266,3 +270,5 @@ extern void set_lf_mode(void);
 extern int getaddrfamily(const char *addr);
 extern int setenv_portable(const char *name, const char *value);
 extern void setup_environment(struct fdinfo *fdinfo);
+
+#endif
