@@ -2,7 +2,7 @@
  * util.c -- Various utility functions.                                    *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2014 Insecure.Com LLC. Nmap is    *
+ * The Nmap Security Scanner is (C) 1996-2015 Insecure.Com LLC. Nmap is    *
  * also a registered trademark of Insecure.Com LLC.  This program is free  *
  * software; you may redistribute and/or modify it under the terms of the  *
  * GNU General Public License as published by the Free Software            *
@@ -93,8 +93,7 @@
  *                                                                         *
  * Source is provided to this software because we believe users have a     *
  * right to know exactly what a program is going to do before they run it. *
- * This also allows you to audit the software for security holes (none     *
- * have been found so far).                                                *
+ * This also allows you to audit the software for security holes.          *
  *                                                                         *
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
@@ -115,11 +114,11 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of              *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
  * license file for more details (it's in a COPYING file included with     *
- * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
+ * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: util.c 33540 2014-08-16 02:45:47Z dmiller $ */
+/* $Id: util.c 34696 2015-06-20 21:56:01Z fyodor $ */
 
 #include "sys_wrap.h"
 #include "util.h"
@@ -441,16 +440,30 @@ int do_listen(int type, int proto, const union sockaddr_u *srcaddr_u)
 #endif
 #endif
 
+    switch(srcaddr_u->storage.ss_family) {
 #ifdef HAVE_SYS_UN_H
-    if (srcaddr_u->storage.ss_family == AF_UNIX)
+      case AF_UNIX:
         sa_len = SUN_LEN(&srcaddr_u->un);
-    else
+        break;
 #endif
 #ifdef HAVE_SOCKADDR_SA_LEN
+      default:
         sa_len = srcaddr_u->sockaddr.sa_len;
+        break;
 #else
-        sa_len = sizeof(*srcaddr_u);
+      case AF_INET:
+        sa_len = sizeof (struct sockaddr_in);
+        break;
+#ifdef AF_INET6
+      case AF_INET6:
+        sa_len = sizeof (struct sockaddr_in6);
+        break;
 #endif
+      default:
+        sa_len = sizeof(*srcaddr_u);
+        break;
+#endif
+    }
 
     if (bind(sock, &srcaddr_u->sockaddr, sa_len) < 0) {
 #ifdef HAVE_SYS_UN_H
