@@ -1,7 +1,6 @@
 #include "nsock.h"
 #include "nmap_error.h"
 #include "NmapOps.h"
-#include "utils.h"
 #include "tcpip.h"
 #include "protocols.h"
 #include "libnetutil/netutil.h"
@@ -71,26 +70,26 @@ static int gc_pool (lua_State *L)
 {
   nsock_pool *nsp = (nsock_pool *) lua_touserdata(L, 1);
   assert(*nsp != NULL);
-  nsp_delete(*nsp);
+  nsock_pool_delete(*nsp);
   *nsp = NULL;
   return 0;
 }
 
 static nsock_pool new_pool (lua_State *L)
 {
-  nsock_pool nsp = nsp_new(NULL);
+  nsock_pool nsp = nsock_pool_new(NULL);
   nsock_pool *nspp;
 
   /* configure logging */
-  nsock_set_log_function(nsp, nmap_nsock_stderr_logger);
-  nmap_adjust_loglevel(nsp, o.scriptTrace());
+  nsock_set_log_function(nmap_nsock_stderr_logger);
+  nmap_adjust_loglevel(o.scriptTrace());
 
-  nsp_setdevice(nsp, o.device);
+  nsock_pool_set_device(nsp, o.device);
 
   if (o.proxy_chain)
-    nsp_set_proxychain(nsp, o.proxy_chain);
+    nsock_pool_set_proxychain(nsp, o.proxy_chain);
 
-  nsp_setbroadcast(nsp, true);
+  nsock_pool_set_broadcast(nsp, true);
 
   nspp = (nsock_pool *) lua_newuserdata(L, sizeof(nsock_pool));
   *nspp = nsp;
@@ -296,7 +295,7 @@ static void trace (nsock_iod nsiod, const char *message, const char *dir)
 {
   if (o.scriptTrace())
   {
-    if (!nsi_is_pcap(nsiod))
+    if (!nsock_iod_is_pcap(nsiod))
     {
       int protocol;
       int af;
@@ -305,7 +304,7 @@ static void trace (nsock_iod nsiod, const char *message, const char *dir)
       struct sockaddr_storage local;
       struct sockaddr_storage remote;
 
-      nsi_getlastcommunicationinfo(nsiod, &protocol, &af,
+      nsock_iod_get_communication_info(nsiod, &protocol, &af,
           (sockaddr *) &local, (sockaddr *) &remote, sizeof(sockaddr_storage));
       log_write(LOG_STDOUT, "%s: %s %s:%d %s %s:%d | %s\n",
           SCRIPT_ENGINE,
@@ -382,17 +381,17 @@ static nse_nsock_udata *check_nsock_udata (lua_State *L, int idx, bool open)
       nsock_pool nsp;
 
       nsp = get_pool(L);
-      nu->nsiod = nsi_new(nsp, NULL);
+      nu->nsiod = nsock_iod_new(nsp, NULL);
       if (nu->source_addr.ss_family != AF_UNSPEC) {
-        nsi_set_localaddr(nu->nsiod, &nu->source_addr, nu->source_addrlen);
+        nsock_iod_set_localaddr(nu->nsiod, &nu->source_addr, nu->source_addrlen);
       } else if (o.spoofsource) {
         struct sockaddr_storage ss;
         size_t sslen;
         o.SourceSockAddr(&ss, &sslen);
-        nsi_set_localaddr(nu->nsiod, &ss, sslen);
+        nsock_iod_set_localaddr(nu->nsiod, &ss, sslen);
       }
       if (o.ipoptionslen)
-        nsi_set_ipoptions(nu->nsiod, o.ipoptions, o.ipoptionslen);
+        nsock_iod_set_ipoptions(nu->nsiod, o.ipoptions, o.ipoptionslen);
 
       if (nsock_setup_udp(nsp, nu->nsiod, nu->af) == -1) {
         luaL_error(L, "Error in setup of iod with proto %d and af %d: %s (%d)",
@@ -419,7 +418,7 @@ static int l_loop (lua_State *L)
 
   socket_unlock(L); /* clean up old socket locks */
 
-  nmap_adjust_loglevel(nsp, o.scriptTrace());
+  nmap_adjust_loglevel(o.scriptTrace());
   if (nsock_loop(nsp, tout) == NSOCK_LOOP_ERROR)
     return luaL_error(L, "a fatal error occurred in nsock_loop");
   return 0;
@@ -478,7 +477,18 @@ static int l_connect (lua_State *L)
     return nseU_safeerror(L, "sorry, you don't have OpenSSL");
 #endif
 
-  error_id = getaddrinfo(addr, NULL, NULL, &dest);
+  /* If we're connecting by name, we should use the same AF as our scan */
+  struct addrinfo hints = {0};
+  /* First check if it's a numeric address */
+  hints.ai_flags = AI_NUMERICHOST;
+  error_id = getaddrinfo(addr, NULL, &hints, &dest);
+  if (error_id == EAI_NONAME) {
+    /* Nope, let's resolve it for the proper AF */
+    hints.ai_flags = 0;
+    hints.ai_family = o.af();
+    error_id = getaddrinfo(addr, NULL, &hints, &dest);
+  }
+
   if (error_id)
     return nseU_safeerror(L, gai_strerror(error_id));
 
@@ -487,21 +497,21 @@ static int l_connect (lua_State *L)
 
   if (nu->nsiod != NULL)
     close_internal(L, nu);
-  nu->nsiod = nsi_new(nsp, NULL);
+  nu->nsiod = nsock_iod_new(nsp, NULL);
   if (nu->source_addr.ss_family != AF_UNSPEC) {
-    nsi_set_localaddr(nu->nsiod, &nu->source_addr, nu->source_addrlen);
+    nsock_iod_set_localaddr(nu->nsiod, &nu->source_addr, nu->source_addrlen);
   } else if (o.spoofsource) {
     struct sockaddr_storage ss;
     size_t sslen;
 
     o.SourceSockAddr(&ss, &sslen);
-    nsi_set_localaddr(nu->nsiod, &ss, sslen);
+    nsock_iod_set_localaddr(nu->nsiod, &ss, sslen);
   }
   if (o.ipoptionslen)
-    nsi_set_ipoptions(nu->nsiod, o.ipoptions, o.ipoptionslen);
+    nsock_iod_set_ipoptions(nu->nsiod, o.ipoptions, o.ipoptionslen);
   if (targetname != NULL) {
-    if (nsi_set_hostname(nu->nsiod, targetname) == -1)
-      fatal("nsi_set_hostname(\"%s\" failed in %s()", targetname, __func__);
+    if (nsock_iod_set_hostname(nu->nsiod, targetname) == -1)
+      fatal("nsock_iod_set_hostname(\"%s\" failed in %s()", targetname, __func__);
   }
 
   nu->af = dest->ai_addr->sa_family;
@@ -695,7 +705,7 @@ static int l_get_info (lua_State *L)
   char *ipstring_local = (char *) lua_newuserdata(L, sizeof(char) * INET6_ADDRSTRLEN);
   char *ipstring_remote = (char *) lua_newuserdata(L, sizeof(char) * INET6_ADDRSTRLEN);
 
-  nsi_getlastcommunicationinfo(nu->nsiod, &protocol, &af,
+  nsock_iod_get_communication_info(nu->nsiod, &protocol, &af,
       (struct sockaddr*)&local, (struct sockaddr*)&remote,
       sizeof(struct sockaddr_storage));
 
@@ -764,17 +774,22 @@ SSL *nse_nsock_get_ssl (lua_State *L)
 {
   nse_nsock_udata *nu = check_nsock_udata(L, 1, false);
 
-  if (nu->nsiod == NULL || !nsi_checkssl(nu->nsiod))
+  if (nu->nsiod == NULL || !nsock_iod_check_ssl(nu->nsiod))
     luaL_argerror(L, 1, "not a SSL socket");
 
-  return (SSL *) nsi_getssl(nu->nsiod);
+  return (SSL *) nsock_iod_get_ssl(nu->nsiod);
 }
 #else
-/* If HAVE_OPENSSL is defined, this comes from nse_ssl_cert.cc. */
+/* If HAVE_OPENSSL is defined, these come from nse_ssl_cert.cc. */
 int l_get_ssl_certificate (lua_State *L)
 {
   return luaL_error(L, "SSL is not available");
 }
+
+int l_parse_ssl_certificate(lua_State *L)
+{
+  return luaL_error(L, "SSL is not available");
+}
 #endif
 
 /* Set the local address for socket operations. The two optional parameters
@@ -813,11 +828,12 @@ static int l_bind (lua_State *L)
   }
 
   /* We ignore any results after the first. */
-  /* We would just call nsi_set_localaddr here, but nu->nsiod is not created
-     until connect. So store the address in the userdatum. */
+  /* We would just call nsock_iod_set_localaddr here, but nu->nsiod is not
+   * created until connect. So store the address in the userdatum. */
   nu->source_addrlen = results->ai_addrlen;
   memcpy(&nu->source_addr, results->ai_addr, nu->source_addrlen);
 
+  freeaddrinfo(results);
   return nseU_success(L);
 }
 
@@ -882,7 +898,7 @@ static void close_internal (lua_State *L, nse_nsock_udata *nu)
     SSL_SESSION_free((SSL_SESSION *) nu->ssl_session);
 #endif
   if (!nu->is_pcap) { /* pcap sockets are closed by pcap_gc */
-    nsi_delete(nu->nsiod, NSOCK_PENDING_NOTIFY);
+    nsock_iod_delete(nu->nsiod, NSOCK_PENDING_NOTIFY);
     nu->nsiod = NULL;
   }
 }
@@ -931,7 +947,7 @@ static void dnet_to_pcap_device_name (lua_State *L, const char *device)
 static int pcap_gc (lua_State *L)
 {
   nsock_iod *nsiod = (nsock_iod *) lua_touserdata(L, 1);
-  nsi_delete(*nsiod, NSOCK_PENDING_NOTIFY);
+  nsock_iod_delete(*nsiod, NSOCK_PENDING_NOTIFY);
   *nsiod = NULL;
   return 0;
 }
@@ -968,7 +984,7 @@ static int l_pcap_open (lua_State *L)
     nsiod = (nsock_iod *) lua_newuserdata(L, sizeof(nsock_iod));
     lua_pushvalue(L, PCAP_SOCKET);
     lua_setmetatable(L, -2);
-    *nsiod = nsi_new(nsp, nu);
+    *nsiod = nsock_iod_new(nsp, nu);
     lua_pushvalue(L, 7); /* the pcap socket key */
     lua_pushvalue(L, -2); /* the pcap socket nsiod */
     lua_rawset(L, KEY_PCAP); /* KEY_PCAP["dev|snap|promis|bpf"] = pcap_nsiod */
@@ -1047,6 +1063,7 @@ LUALIB_API int luaopen_nsock (lua_State *L)
     {"loop", l_loop},
     {"new", l_new},
     {"sleep", l_sleep},
+    {"parse_ssl_certificate", l_parse_ssl_certificate},
     {NULL, NULL}
   };
 
@@ -1093,7 +1110,7 @@ LUALIB_API int luaopen_nsock (lua_State *L)
 
 #if HAVE_OPENSSL
   /* Value speed over security in SSL connections. */
-  nsp_ssl_init_max_speed(nsp);
+  nsock_pool_ssl_init(nsp, NSOCK_SSL_MAX_SPEED);
 #endif
 
   luaL_newlibtable(L, l_nsock);
