@@ -4,7 +4,7 @@
  *                                                                         *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2014 Insecure.Com LLC. Nmap is    *
+ * The Nmap Security Scanner is (C) 1996-2015 Insecure.Com LLC. Nmap is    *
  * also a registered trademark of Insecure.Com LLC.  This program is free  *
  * software; you may redistribute and/or modify it under the terms of the  *
  * GNU General Public License as published by the Free Software            *
@@ -95,8 +95,7 @@
  *                                                                         *
  * Source is provided to this software because we believe users have a     *
  * right to know exactly what a program is going to do before they run it. *
- * This also allows you to audit the software for security holes (none     *
- * have been found so far).                                                *
+ * This also allows you to audit the software for security holes.          *
  *                                                                         *
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
@@ -117,7 +116,7 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of              *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
  * license file for more details (it's in a COPYING file included with     *
- * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
+ * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
  *                                                                         *
  ***************************************************************************/
 
@@ -306,8 +305,8 @@ static int time_to_tm(const ASN1_TIME *t, struct tm *result)
     else
       result->tm_year = 1900 + year;
     p = t->data + 2;
-  } else if (t->length == 14) {
-    /* yyyymmddhhmmss */
+  } else if (t->length == 15 && t->data[t->length - 1] == 'Z') {
+    /* yyyymmddhhmmssZ */
     result->tm_year = parse_int(t->data, 4);
     if (result->tm_year < 0)
       return -1;
@@ -427,13 +426,76 @@ static const char *pkey_type_to_string(int type)
   }
 }
 
+void lua_push_ecdhparams(lua_State *L, EVP_PKEY *pubkey) {
+#ifdef EC_KEY
+  EC_KEY *ec_key = EVP_PKEY_get1_EC_KEY(pubkey);
+  const EC_GROUP *group = EC_KEY_get0_group(ec_key);
+  int nid;
+  if ((nid = EC_GROUP_get_curve_name(group)) != 0) {
+    lua_newtable(L);
+    lua_newtable(L);
+    lua_pushstring(L, OBJ_nid2sn(nid));
+    lua_setfield(L, -2, "curve");
+    lua_pushstring(L, "namedcurve");
+    lua_setfield(L, -2, "ec_curve_type");
+    lua_setfield(L, -2, "curve_params");
+    lua_setfield(L, -2, "ecdhparams");
+  }
+  else {
+    /* According to RFC 5480 section 2.1.1, explicit curves must not be used with
+       X.509. This may change in the future, but for now it doesn't seem worth it
+       to add in code to extract the extra parameters. */
+    nid = EC_METHOD_get_field_type(EC_GROUP_method_of(group));
+    if (nid == NID_X9_62_prime_field) {
+      lua_newtable(L);
+      lua_newtable(L);
+      lua_pushstring(L, "explicit_prime");
+      lua_setfield(L, -2, "ec_curve_type");
+      lua_setfield(L, -2, "curve_params");
+      lua_setfield(L, -2, "ecdhparams");
+    }
+    else if (nid == NID_X9_62_characteristic_two_field) {
+      lua_newtable(L);
+      lua_newtable(L);
+      lua_pushstring(L, "explicit_char2");
+      lua_setfield(L, -2, "ec_curve_type");
+      lua_setfield(L, -2, "curve_params");
+      lua_setfield(L, -2, "ecdhparams");
+    }
+    else {
+      /* Something wierd happened. */
+    }
+  }
+  EC_KEY_free(ec_key);
+#endif
+}
+
+static int parse_ssl_cert(lua_State *L, X509 *cert);
+
+int l_parse_ssl_certificate(lua_State *L)
+{
+  X509 *cert;
+  size_t l;
+  const char *der;
+
+  der = luaL_checklstring(L, 1, &l);
+  if (der == NULL) {
+    lua_pushnil(L);
+    return 1;
+  }
+
+  cert = d2i_X509(NULL, (const unsigned char **) &der, l);
+  if (cert == NULL) {
+    lua_pushnil(L);
+    return 1;
+  }
+  return parse_ssl_cert(L, cert);
+}
+
 int l_get_ssl_certificate(lua_State *L)
 {
   SSL *ssl;
-  struct cert_userdata *udata;
   X509 *cert;
-  X509_NAME *subject, *issuer;
-  EVP_PKEY *pubkey;
 
   ssl = nse_nsock_get_ssl(L);
   cert = SSL_get_peer_certificate(ssl);
@@ -441,6 +503,15 @@ int l_get_ssl_certificate(lua_State *L)
     lua_pushnil(L);
     return 1;
   }
+  return parse_ssl_cert(L, cert);
+}
+
+static int parse_ssl_cert(lua_State *L, X509 *cert)
+{
+  struct cert_userdata *udata;
+  X509_NAME *subject, *issuer;
+  EVP_PKEY *pubkey;
+  int pkey_type;
 
   udata = (struct cert_userdata *) lua_newuserdata(L, sizeof(*udata));
   udata->cert = cert;
@@ -453,6 +524,10 @@ int l_get_ssl_certificate(lua_State *L)
     lua_setfield(L, -2, "subject");
   }
 
+  const char *sig_algo = OBJ_nid2ln(OBJ_obj2nid(cert->sig_alg->algorithm));
+  lua_pushstring(L, sig_algo);
+  lua_setfield(L, -2, "sig_algorithm");
+
   issuer = X509_get_issuer_name(cert);
   if (issuer != NULL) {
     x509_name_to_table(L, issuer);
@@ -467,7 +542,11 @@ int l_get_ssl_certificate(lua_State *L)
 
   pubkey = X509_get_pubkey(cert);
   lua_newtable(L);
-  lua_pushstring(L, pkey_type_to_string(pubkey->type));
+  pkey_type = EVP_PKEY_type(pubkey->type);
+  if (pkey_type == EVP_PKEY_EC) {
+    lua_push_ecdhparams(L, pubkey);
+  }
+  lua_pushstring(L, pkey_type_to_string(pkey_type));
   lua_setfield(L, -2, "type");
   lua_pushnumber(L, EVP_PKEY_bits(pubkey));
   lua_setfield(L, -2, "bits");
@@ -491,7 +570,7 @@ int l_get_ssl_certificate(lua_State *L)
 static int l_ssl_cert_index(lua_State *L)
 {
   struct cert_userdata *udata;
-  
+
   udata = (struct cert_userdata *) luaL_checkudata(L, 1, "SSL_CERT");
   lua_rawgeti(L, LUA_REGISTRYINDEX, udata->attributes_table);
   /* The key. */
@@ -505,7 +584,7 @@ static int l_ssl_cert_index(lua_State *L)
 static int l_ssl_cert_gc(lua_State *L)
 {
   struct cert_userdata *udata;
-  
+
   udata = (struct cert_userdata *) luaL_checkudata(L, 1, "SSL_CERT");
   X509_free(udata->cert);
   luaL_unref(L, LUA_REGISTRYINDEX, udata->attributes_table);
