@@ -3,7 +3,7 @@
  *                                                                         *
  ***********************IMPORTANT NSOCK LICENSE TERMS***********************
  *                                                                         *
- * The nsock parallel socket event library is (C) 1999-2013 Insecure.Com   *
+ * The nsock parallel socket event library is (C) 1999-2015 Insecure.Com   *
  * LLC This library is free software; you may redistribute and/or          *
  * modify it under the terms of the GNU General Public License as          *
  * published by the Free Software Foundation; Version 2.  This guarantees  *
@@ -27,8 +27,7 @@
  *                                                                         *
  * Source is provided to this software because we believe users have a     *
  * right to know exactly what a program is going to do before they run it. *
- * This also allows you to audit the software for security holes (none     *
- * have been found so far).                                                *
+ * This also allows you to audit the software for security holes.          *
  *                                                                         *
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
@@ -53,7 +52,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: engine_select.c 32685 2014-01-30 19:02:57Z henri $ */
+/* $Id: engine_select.c 34756 2015-06-27 08:21:53Z henri $ */
 
 #ifndef WIN32
 #include <sys/select.h>
@@ -70,12 +69,12 @@
 
 
 /* --- ENGINE INTERFACE PROTOTYPES --- */
-static int select_init(mspool *nsp);
-static void select_destroy(mspool *nsp);
-static int select_iod_register(mspool *nsp, msiod *iod, int ev);
-static int select_iod_unregister(mspool *nsp, msiod *iod);
-static int select_iod_modify(mspool *nsp, msiod *iod, int ev_set, int ev_clr);
-static int select_loop(mspool *nsp, int msec_timeout);
+static int select_init(struct npool *nsp);
+static void select_destroy(struct npool *nsp);
+static int select_iod_register(struct npool *nsp, struct niod *iod, int ev);
+static int select_iod_unregister(struct npool *nsp, struct niod *iod);
+static int select_iod_modify(struct npool *nsp, struct niod *iod, int ev_set, int ev_clr);
+static int select_loop(struct npool *nsp, int msec_timeout);
 
 
 /* ---- ENGINE DEFINITION ---- */
@@ -91,21 +90,21 @@ struct io_engine engine_select = {
 
 
 /* --- INTERNAL PROTOTYPES --- */
-static void iterate_through_event_lists(mspool *nsp);
+static void iterate_through_event_lists(struct npool *nsp);
 
 /* defined in nsock_core.c */
-void process_event(mspool *nsp, gh_list_t *evlist, msevent *nse, int ev);
-void process_iod_events(mspool *nsp, msiod *nsi, int ev);
-void process_expired_events(mspool *nsp);
+void process_event(struct npool *nsp, gh_list_t *evlist, struct nevent *nse, int ev);
+void process_iod_events(struct npool *nsp, struct niod *nsi, int ev);
+void process_expired_events(struct npool *nsp);
 
 #if HAVE_PCAP
 #ifndef PCAP_CAN_DO_SELECT
-int pcap_read_on_nonselect(mspool *nsp);
+int pcap_read_on_nonselect(struct npool *nsp);
 #endif
 #endif
 
 /* defined in nsock_event.c */
-void update_first_events(msevent *nse);
+void update_first_events(struct nevent *nse);
 
 
 extern struct timeval nsock_tod;
@@ -133,7 +132,7 @@ struct select_engine_info {
 };
 
 
-int select_init(mspool *nsp) {
+int select_init(struct npool *nsp) {
   struct select_engine_info *sinfo;
 
   sinfo = (struct select_engine_info *)safe_malloc(sizeof(struct select_engine_info));
@@ -149,12 +148,12 @@ int select_init(mspool *nsp) {
   return 1;
 }
 
-void select_destroy(mspool *nsp) {
+void select_destroy(struct npool *nsp) {
   assert(nsp->engine_data != NULL);
   free(nsp->engine_data);
 }
 
-int select_iod_register(mspool *nsp, msiod *iod, int ev) {
+int select_iod_register(struct npool *nsp, struct niod *iod, int ev) {
   assert(!IOD_PROPGET(iod, IOD_REGISTERED));
 
   iod->watched_events = ev;
@@ -163,7 +162,7 @@ int select_iod_register(mspool *nsp, msiod *iod, int ev) {
   return 1;
 }
 
-int select_iod_unregister(mspool *nsp, msiod *iod) {
+int select_iod_unregister(struct npool *nsp, struct niod *iod) {
   struct select_engine_info *sinfo = (struct select_engine_info *)nsp->engine_data;
 
   iod->watched_events = EV_NONE;
@@ -197,7 +196,7 @@ int select_iod_unregister(mspool *nsp, msiod *iod) {
   return 1;
 }
 
-int select_iod_modify(mspool *nsp, msiod *iod, int ev_set, int ev_clr) {
+int select_iod_modify(struct npool *nsp, struct niod *iod, int ev_set, int ev_clr) {
   int sd;
   struct select_engine_info *sinfo = (struct select_engine_info *)nsp->engine_data;
 
@@ -206,7 +205,7 @@ int select_iod_modify(mspool *nsp, msiod *iod, int ev_set, int ev_clr) {
   iod->watched_events |= ev_set;
   iod->watched_events &= ~ev_clr;
 
-  sd = nsi_getsd(iod);
+  sd = nsock_iod_get_sd(iod);
 
   /* -- set events -- */
   if (ev_set & EV_READ)
@@ -238,7 +237,7 @@ int select_iod_modify(mspool *nsp, msiod *iod, int ev_set, int ev_clr) {
   return 1;
 }
 
-int select_loop(mspool *nsp, int msec_timeout) {
+int select_loop(struct npool *nsp, int msec_timeout) {
   int results_left = 0;
   int event_msecs; /* msecs before an event goes off */
   int combined_msecs;
@@ -253,9 +252,9 @@ int select_loop(mspool *nsp, int msec_timeout) {
     return 0; /* No need to wait on 0 events ... */
 
   do {
-    msevent *nse;
+    struct nevent *nse;
 
-    nsock_log_debug_all(nsp, "wait for events");
+    nsock_log_debug_all("wait for events");
 
     nse = next_expirable_event(nsp);
     if (!nse)
@@ -317,7 +316,7 @@ int select_loop(mspool *nsp, int msec_timeout) {
   } while (results_left == -1 && sock_err == EINTR); /* repeat only if signal occurred */
 
   if (results_left == -1 && sock_err != EINTR) {
-    nsock_log_error(nsp, "nsock_loop error %d: %s", sock_err, socket_strerror(sock_err));
+    nsock_log_error("nsock_loop error %d: %s", sock_err, socket_strerror(sock_err));
     nsp->errnum = sock_err;
     return -1;
   }
@@ -330,7 +329,7 @@ int select_loop(mspool *nsp, int msec_timeout) {
 
 /* ---- INTERNAL FUNCTIONS ---- */
 
-static inline int get_evmask(const mspool *nsp, const msiod *nsi) {
+static inline int get_evmask(const struct npool *nsp, const struct niod *nsi) {
   struct select_engine_info *sinfo = (struct select_engine_info *)nsp->engine_data;
   int sd, evmask;
 
@@ -369,7 +368,7 @@ static inline int get_evmask(const mspool *nsp, const msiod *nsi) {
 /* Iterate through all the event lists (such as connect_events, read_events,
  * timer_events, etc) and take action for those that have completed (due to
  * timeout, i/o, etc) */
-void iterate_through_event_lists(mspool *nsp) {
+void iterate_through_event_lists(struct npool *nsp) {
   gh_lnode_t *current, *next, *last;
 
   last = gh_list_last_elem(&nsp->active_iods);
@@ -377,7 +376,7 @@ void iterate_through_event_lists(mspool *nsp) {
   for (current = gh_list_first_elem(&nsp->active_iods);
        current != NULL && gh_lnode_prev(current) != last;
        current = next) {
-    msiod *nsi = container_of(current, msiod, nodeq);
+    struct niod *nsi = container_of(current, struct niod, nodeq);
 
     if (nsi->state != NSIOD_STATE_DELETED && nsi->events_pending)
       process_iod_events(nsp, nsi, get_evmask(nsp, nsi));
