@@ -9,7 +9,7 @@
  *                                                                         *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2014 Insecure.Com LLC. Nmap is    *
+ * The Nmap Security Scanner is (C) 1996-2015 Insecure.Com LLC. Nmap is    *
  * also a registered trademark of Insecure.Com LLC.  This program is free  *
  * software; you may redistribute and/or modify it under the terms of the  *
  * GNU General Public License as published by the Free Software            *
@@ -100,8 +100,7 @@
  *                                                                         *
  * Source is provided to this software because we believe users have a     *
  * right to know exactly what a program is going to do before they run it. *
- * This also allows you to audit the software for security holes (none     *
- * have been found so far).                                                *
+ * This also allows you to audit the software for security holes.          *
  *                                                                         *
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
@@ -122,11 +121,11 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of              *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
  * license file for more details (it's in a COPYING file included with     *
- * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
+ * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: output.h 33540 2014-08-16 02:45:47Z dmiller $ */
+/* $Id: output.h 35347 2015-10-26 16:16:02Z dmiller $ */
 
 #ifndef OUTPUT_H
 #define OUTPUT_H
@@ -163,11 +162,15 @@
  "think Solaris can support advanced localhost scans.  You can probably "\
  "use \"-Pn -sT localhost\" though.\n\n"
 
-#include "portlist.h"
 #include "nmap.h"
-#include "global_structures.h"
+#ifndef NOLUA
+#include "nse_main.h"
+#endif
 #include <nsock.h>
+class PortList;
+class Target;
 
+#include <stdarg.h>
 #include <string>
 
 #ifdef WIN32
@@ -286,7 +289,8 @@ void printfinaloutput();
 void printdatafilepaths();
 
 /* nsock logging interface */
-void nmap_adjust_loglevel(nsock_pool nsp, bool trace);
-void nmap_nsock_stderr_logger(nsock_pool nsp, const struct nsock_log_rec *rec);
+void nmap_adjust_loglevel(bool trace);
+void nmap_nsock_stderr_logger(const struct nsock_log_rec *rec);
 
 #endif /* OUTPUT_H */
+
