@@ -6,7 +6,7 @@
  *                                                                         *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2014 Insecure.Com LLC. Nmap is    *
+ * The Nmap Security Scanner is (C) 1996-2015 Insecure.Com LLC. Nmap is    *
  * also a registered trademark of Insecure.Com LLC.  This program is free  *
  * software; you may redistribute and/or modify it under the terms of the  *
  * GNU General Public License as published by the Free Software            *
@@ -97,8 +97,7 @@
  *                                                                         *
  * Source is provided to this software because we believe users have a     *
  * right to know exactly what a program is going to do before they run it. *
- * This also allows you to audit the software for security holes (none     *
- * have been found so far).                                                *
+ * This also allows you to audit the software for security holes.          *
  *                                                                         *
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
@@ -119,11 +118,11 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of              *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
  * license file for more details (it's in a COPYING file included with     *
- * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
+ * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: targets.cc 33540 2014-08-16 02:45:47Z dmiller $ */
+/* $Id: targets.cc 35347 2015-10-26 16:16:02Z dmiller $ */
 
 
 #include "nbase/nbase_addrset.h"
@@ -341,6 +340,11 @@ static bool target_needs_new_hostgroup(const HostGroupState *hs, const Target *t
   return false;
 }
 
+TargetGroup::~TargetGroup() {
+  if (this->netblock != NULL)
+    delete this->netblock;
+}
+
 /* Initializes (or reinitializes) the object with a new expression, such
    as 192.168.0.0/16 , 10.1.0-5.1-254 , or fe80::202:e3ff:fe14:1102 .
    Returns 0 for success */
@@ -373,6 +377,7 @@ int TargetGroup::get_next_host(struct sockaddr_storage *ss, size_t *sslen) {
     this->netblock = netblock_hostname->resolve();
     if (this->netblock == NULL) {
       error("Failed to resolve \"%s\".", netblock_hostname->hostname.c_str());
+      delete netblock_hostname;
       return -1;
     }
     delete netblock_hostname;
@@ -458,8 +463,6 @@ void HostGroupState::undefer() {
 }
 
 const char *HostGroupState::next_expression() {
-  static char buf[1024];
-
   if (o.max_ips_to_scan == 0 || o.numhosts_scanned + this->current_batch_sz < o.max_ips_to_scan) {
     const char *expr;
     expr = grab_next_host_spec(o.inputfd, o.generate_random_ips, this->argc, this->argv);
@@ -469,6 +472,7 @@ const char *HostGroupState::next_expression() {
 
 #ifndef NOLUA
   /* Add any new NSE discovered targets to the scan queue */
+  static char buf[1024];
 
   NewTargets *new_targets = NewTargets::get();
   if (o.script && new_targets != NULL) {
@@ -643,6 +647,7 @@ static void refresh_hostbatch(HostGroupState *hs, const addrset *exclude_group,
         break;
     }
 
+    o.decoys[o.decoyturn] = t->v4source();
     hs->hostbatch[hs->current_batch_sz++] = t;
   }
 
