@@ -4,7 +4,7 @@
  *                                                                         *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2014 Insecure.Com LLC. Nmap is    *
+ * The Nmap Security Scanner is (C) 1996-2015 Insecure.Com LLC. Nmap is    *
  * also a registered trademark of Insecure.Com LLC.  This program is free  *
  * software; you may redistribute and/or modify it under the terms of the  *
  * GNU General Public License as published by the Free Software            *
@@ -95,8 +95,7 @@
  *                                                                         *
  * Source is provided to this software because we believe users have a     *
  * right to know exactly what a program is going to do before they run it. *
- * This also allows you to audit the software for security holes (none     *
- * have been found so far).                                                *
+ * This also allows you to audit the software for security holes.          *
  *                                                                         *
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
@@ -117,54 +116,22 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of              *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
  * license file for more details (it's in a COPYING file included with     *
- * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
+ * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: utils.h 33540 2014-08-16 02:45:47Z dmiller $ */
+/* $Id: utils.h 34809 2015-07-01 03:35:08Z dmiller $ */
 
 #ifndef UTILS_H
 #define UTILS_H
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdarg.h>
-#include <string.h>
-#include <errno.h>
-#include <ctype.h>
-#include "nmap.h"
-#ifdef WIN32
-#include "mswin32\winclude.h"
-#else
-#include <sys/types.h>
-
-#if HAVE_NETINET_IN_H
-#include <netinet/in.h>
-#endif
-
+#ifndef WIN32
 #include <sys/mman.h>
-#include "nmap_config.h"
-#endif
-
-#if HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-
-#if TIME_WITH_SYS_TIME
-# include <sys/time.h>
-# include <time.h>
-#else
-# if HAVE_SYS_TIME_H
-#  include <sys/time.h>
-# else
-#  include <time.h>
-# endif
 #endif
 
 #include "nbase.h"
 
 #include "nmap_error.h"
-#include "global_structures.h"
 
 /* Arithmatic difference modulo 2^32 */
 #ifndef MOD_DIFF
@@ -214,6 +181,8 @@ char *cstring_unescape(char *str, unsigned int *len);
 
 void bintohexstr(char *buf, int buflen, char *src, int srclen);
 
+u8 *parse_hex_string(char *str, size_t *outlen);
+
 #ifndef HAVE_STRERROR
 char *strerror(int errnum);
 #endif
@@ -227,3 +196,4 @@ int win32_munmap(char *filestr, int filelen);
 #endif /* WIN32 */
 
 #endif /* UTILS_H */
+
