@@ -2,7 +2,7 @@
  * xml.cc -- Simple library to emit XML.                                   *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2014 Insecure.Com LLC. Nmap is    *
+ * The Nmap Security Scanner is (C) 1996-2015 Insecure.Com LLC. Nmap is    *
  * also a registered trademark of Insecure.Com LLC.  This program is free  *
  * software; you may redistribute and/or modify it under the terms of the  *
  * GNU General Public License as published by the Free Software            *
@@ -93,8 +93,7 @@
  *                                                                         *
  * Source is provided to this software because we believe users have a     *
  * right to know exactly what a program is going to do before they run it. *
- * This also allows you to audit the software for security holes (none     *
- * have been found so far).                                                *
+ * This also allows you to audit the software for security holes.          *
  *                                                                         *
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
@@ -115,7 +114,7 @@
  * WITHOUT ANY WARRANTY; without even the implied warranty of              *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
  * license file for more details (it's in a COPYING file included with     *
- * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
+ * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
  *                                                                         *
  ***************************************************************************/
 
@@ -125,12 +124,13 @@
 This is a simple library for writing XML. It handles two main things:
 keeping track of the element stack, and escaping text where necessary.
 If you wanted to write this XML:
-  <?xml version="1.0"?>
+  <?xml version="1.0" encoding="UTF-8"?>
+  <!DOCTYPE elem>
   <elem name="&amp;10.5"></elem>
 these are the functions you would call. Each one is followed by the text
 it prints enclosed in ||.
 
-xml_start_document()                   |<?xml version="1.0"?>|
+xml_start_document("elem")             |<?xml version="1.0" encoding="UTF-8"?>\n<!DOCTYPE elem>|
 xml_newline();                         |\n|
 xml_open_start_tag("elem");            |<elem|
 xml_attribute("name", "&%.1f", 10.5);  | name="&amp;10.5"|
@@ -167,7 +167,7 @@ Additional functions are
 xml_write_raw                 Raw unescaped output.
 xml_write_escaped             XML-escaped output.
 xml_write_escaped_v           XML-escaped output, with a va_list.
-xml_start_document            Writes <?xml version="1.0"?>.
+xml_start_document            Writes <?xml version="1.0" encoding="UTF-8"?>\n<!DOCTYPE elem>.
 xml_depth                     Returns the size of the element stack.
 
 The library makes it harder but not impossible to make non-well-formed
@@ -309,7 +309,7 @@ int xml_write_escaped_v(const char *fmt, va_list va) {
   return 0;
 }
 
-/* Write the XML declaration: <?xml version="1.0"?>
+/* Write the XML declaration: <?xml version="1.0" encoding="UTF-8"?>
  * and the DOCTYPE declaration: <!DOCTYPE rootnode>
  */
 int xml_start_document(const char *rootnode) {
@@ -317,6 +317,10 @@ int xml_start_document(const char *rootnode) {
     return -1;
   if (xml_attribute("version", "1.0") < 0)
     return -1;
+  /* Practically, Nmap only uses ASCII, but UTF-8 encompasses ASCII and allows
+   * for future expansion */
+  if (xml_attribute("encoding", "UTF-8") < 0)
+    return -1;
   if (xml_close_pi() < 0)
     return -1;
   if (xml_newline() < 0)
