@@ -2,7 +2,7 @@
 
 # ***********************IMPORTANT NMAP LICENSE TERMS************************
 # *                                                                         *
-# * The Nmap Security Scanner is (C) 1996-2014 Insecure.Com LLC. Nmap is    *
+# * The Nmap Security Scanner is (C) 1996-2015 Insecure.Com LLC. Nmap is    *
 # * also a registered trademark of Insecure.Com LLC.  This program is free  *
 # * software; you may redistribute and/or modify it under the terms of the  *
 # * GNU General Public License as published by the Free Software            *
@@ -93,8 +93,7 @@
 # *                                                                         *
 # * Source is provided to this software because we believe users have a     *
 # * right to know exactly what a program is going to do before they run it. *
-# * This also allows you to audit the software for security holes (none     *
-# * have been found so far).                                                *
+# * This also allows you to audit the software for security holes.          *
 # *                                                                         *
 # * Source code also allows you to port Nmap to new platforms, fix bugs,    *
 # * and add new features.  You are highly encouraged to send your changes   *
@@ -115,7 +114,7 @@
 # * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 # * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
 # * license file for more details (it's in a COPYING file included with     *
-# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
+# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
 # *                                                                         *
 # ***************************************************************************/
 
@@ -176,11 +175,22 @@ class TracerouteHostInfo(object):
     hostnames = property(lambda self: self.hostname and [self.hostname] or [])
 
 
+def find_hop_by_ttl(hops, ttl):
+    assert ttl >= 0, "ttl must be non-negative"
+    if ttl == 0: # Same machine (i.e. localhost)
+        return {"ipaddr": "127.0.0.1/8"}
+    for h in hops:
+        if ttl == int(h["ttl"]):
+            return h
+    return None
+
 def make_graph_from_hosts(hosts):
     #hosts = parser.get_root().search_children('host', deep=True)
     graph = Graph()
     nodes = list()
     node_cache = {}
+    ancestor_node_cache = {}
+    descendant_node_cache = {}
 
     # Setting initial reference host
     main_node = NetNode()
@@ -210,13 +220,7 @@ def make_graph_from_hosts(hosts):
             # Getting nodes of host by ttl
             for ttl in range(1, max(ttls) + 1):
                 if ttl in ttls:
-                    # Find a hop by ttl
-                    hop = None
-                    for h in hops:
-                        if ttl == int(h["ttl"]):
-                            hop = h
-                            break
-
+                    hop = find_hop_by_ttl(hops, ttl)
                     node = node_cache.get(hop["ipaddr"])
                     if node is None:
                         node = NetNode()
@@ -245,14 +249,50 @@ def make_graph_from_hosts(hosts):
                     else:
                         graph.set_connection(node, prev_node)
                 else:
-                    node = NetNode()
-                    nodes.append(node)
+                    # Add an "anonymous" node only if there isn't already a node
+                    # equivalent to it (i.e. at same distance from the previous 
+                    # "real" node)
 
-                    node.set_draw_info({"valid": False})
-                    node.set_draw_info(
-                            {"color": (1, 1, 1), "radius": NONE_RADIUS})
+                    pre_hop = None
+                    pre_hop_distance = 0
+                    for i in range(1, ttl + 1):
+                        pre_hop = find_hop_by_ttl(hops, ttl-i)
+                        if pre_hop is not None:
+                            pre_hop_distance = i
+                            break
 
-                    graph.set_connection(node, prev_node)
+                    post_hop = None
+                    post_hop_distance = 0
+                    for i in range(1, max(ttls) - ttl):
+                        post_hop = find_hop_by_ttl(hops, ttl+i)
+                        if post_hop is not None:
+                            post_hop_distance = i
+                            break
+
+                    assert pre_hop is not None, "pre_hop should have become localhost if nothing else"
+
+                    ancestor_key = (pre_hop["ipaddr"], pre_hop_distance)
+                    descendant_key = None
+                    if post_hop is not None:
+                        descendant_key = (post_hop["ipaddr"], post_hop_distance)
+
+                    if ancestor_key in ancestor_node_cache:
+                        node = ancestor_node_cache[ancestor_key]
+                    elif descendant_key is not None and descendant_key in descendant_node_cache:
+                        node = descendant_node_cache[descendant_key]
+                        graph.set_connection(node, prev_node)
+                    else:
+                        node = NetNode()
+                        nodes.append(node)
+
+                        node.set_draw_info({"valid":False})
+                        node.set_draw_info({"color":(1,1,1), "radius":NONE_RADIUS})
+
+                        graph.set_connection(node, prev_node)
+
+                        ancestor_node_cache[ancestor_key] = node
+                        if descendant_key is not None:
+                            descendant_node_cache[descendant_key] = node
 
                 prev_node = node
                 endpoints[host] = node
