@@ -3,7 +3,7 @@
 
 # ***********************IMPORTANT NMAP LICENSE TERMS************************
 # *                                                                         *
-# * The Nmap Security Scanner is (C) 1996-2014 Insecure.Com LLC. Nmap is    *
+# * The Nmap Security Scanner is (C) 1996-2015 Insecure.Com LLC. Nmap is    *
 # * also a registered trademark of Insecure.Com LLC.  This program is free  *
 # * software; you may redistribute and/or modify it under the terms of the  *
 # * GNU General Public License as published by the Free Software            *
@@ -94,8 +94,7 @@
 # *                                                                         *
 # * Source is provided to this software because we believe users have a     *
 # * right to know exactly what a program is going to do before they run it. *
-# * This also allows you to audit the software for security holes (none     *
-# * have been found so far).                                                *
+# * This also allows you to audit the software for security holes.          *
 # *                                                                         *
 # * Source code also allows you to port Nmap to new platforms, fix bugs,    *
 # * and add new features.  You are highly encouraged to send your changes   *
@@ -116,7 +115,7 @@
 # * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 # * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
 # * license file for more details (it's in a COPYING file included with     *
-# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
+# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
 # *                                                                         *
 # ***************************************************************************/
 
@@ -252,13 +251,22 @@ class NmapCommand(object):
 
     def kill(self):
         """Kill the nmap subprocess."""
+        from time import sleep
+
         log.debug(">>> Killing scan process %s" % self.command_process.pid)
 
         if sys.platform != "win32":
             try:
-                from signal import SIGKILL
-                os.kill(self.command_process.pid, SIGKILL)
-                self.command_process.wait()
+                from signal import SIGTERM, SIGKILL
+                os.kill(self.command_process.pid, SIGTERM)
+                for i in range(10):
+                    sleep(0.5)
+                    if self.command_process.poll() is not None: # Process has been TERMinated
+                        break
+                else:
+                    log.debug(">>> SIGTERM has not worked even after waiting for 5 seconds. Using SIGKILL.")
+                    os.kill(self.command_process.pid, SIGKILL)
+                    self.command_process.wait()
             except:
                 pass
         else:
