@@ -3,7 +3,7 @@
 
 # ***********************IMPORTANT NMAP LICENSE TERMS************************
 # *                                                                         *
-# * The Nmap Security Scanner is (C) 1996-2013 Insecure.Com LLC. Nmap is    *
+# * The Nmap Security Scanner is (C) 1996-2015 Insecure.Com LLC. Nmap is    *
 # * also a registered trademark of Insecure.Com LLC.  This program is free  *
 # * software; you may redistribute and/or modify it under the terms of the  *
 # * GNU General Public License as published by the Free Software            *
@@ -11,7 +11,7 @@
 # * AND EXCEPTIONS DESCRIBED HEREIN.  This guarantees your right to use,    *
 # * modify, and redistribute this software under certain conditions.  If    *
 # * you wish to embed Nmap technology into proprietary software, we sell    *
-# * alternative licenses (contact sales@insecure.com).  Dozens of software  *
+# * alternative licenses (contact sales@nmap.com).  Dozens of software      *
 # * vendors already license Nmap technology such as host discovery, port    *
 # * scanning, OS detection, version detection, and the Nmap Scripting       *
 # * Engine.                                                                 *
@@ -67,7 +67,7 @@
 # * obeying all GPL rules and restrictions.  For example, source code of    *
 # * the whole work must be provided and free redistribution must be         *
 # * allowed.  All GPL references to "this License", are to be treated as    *
-# * including the special and conditions of the license text as well.       *
+# * including the terms and conditions of this license text as well.        *
 # *                                                                         *
 # * Because this license imposes special exceptions to the GPL, Covered     *
 # * Work may not be combined (even as part of a larger work) with plain GPL *
@@ -85,17 +85,16 @@
 # * applications and appliances.  These contracts have been sold to dozens  *
 # * of software vendors, and generally include a perpetual license as well  *
 # * as providing for priority support and updates.  They also fund the      *
-# * continued development of Nmap.  Please email sales@insecure.com for     *
-# * further information.                                                    *
+# * continued development of Nmap.  Please email sales@nmap.com for further *
+# * information.                                                            *
 # *                                                                         *
-# * If you received these files with a written license agreement or         *
-# * contract stating terms other than the terms above, then that            *
-# * alternative license agreement takes precedence over these comments.     *
+# * If you have received a written license agreement or contract for        *
+# * Covered Software stating terms other than these, you may choose to use  *
+# * and redistribute Covered Software under those terms instead of these.   *
 # *                                                                         *
 # * Source is provided to this software because we believe users have a     *
 # * right to know exactly what a program is going to do before they run it. *
-# * This also allows you to audit the software for security holes (none     *
-# * have been found so far).                                                *
+# * This also allows you to audit the software for security holes.          *
 # *                                                                         *
 # * Source code also allows you to port Nmap to new platforms, fix bugs,    *
 # * and add new features.  You are highly encouraged to send your changes   *
@@ -116,7 +115,7 @@
 # * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 # * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
 # * license file for more details (it's in a COPYING file included with     *
-# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
+# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING)        *
 # *                                                                         *
 # ***************************************************************************/
 
@@ -130,10 +129,10 @@ from zenmapCore.UmitLogging import log
 from zenmapCore.UmitConfigParser import UmitConfigParser
 import zenmapCore.I18N
 
-# This is the global configuration parser object that represents the contents of
-# zenmap.conf. It should be initialized once by the application. Most
-# interaction with the global parser is done by other classes in this file, like
-# SearchConfig, that wrap specific configuration sections.
+# This is the global configuration parser object that represents the contents
+# of zenmap.conf. It should be initialized once by the application. Most
+# interaction with the global parser is done by other classes in this file,
+# like SearchConfig, that wrap specific configuration sections.
 config_parser = UmitConfigParser()
 
 # Check if running on Maemo
@@ -144,9 +143,11 @@ try:
 except ImportError:
     pass
 
+
 def is_maemo():
     return MAEMO
 
+
 class SearchConfig(UmitConfigParser, object):
     section_name = "search"
 
@@ -245,10 +246,11 @@ class SearchConfig(UmitConfigParser, object):
 
 class Profile(UmitConfigParser, object):
     """This class represents not just one profile, but a whole collection of
-    them found in a config file such as scan_profiles.usp. The methods therefore
-    all take an argument that is the name of the profile to work on."""
+    them found in a config file such as scan_profiles.usp. The methods
+    therefore all take an argument that is the name of the profile to work
+    on."""
 
-    def __init__(self, user_profile = None, *args):
+    def __init__(self, user_profile=None, *args):
         UmitConfigParser.__init__(self, *args)
 
         if not user_profile:
@@ -272,10 +274,10 @@ class Profile(UmitConfigParser, object):
             return self.set(profile, attribute, value)
 
     def add_profile(self, profile_name, **attributes):
-        """Add a profile with the given name and attributes to the collection of
-        profiles. If a profile with the same name exists, it is not overwritten,
-        and the method returns immediately. The backing file for the profiles is
-        automatically updated."""
+        """Add a profile with the given name and attributes to the collection
+        of profiles. If a profile with the same name exists, it is not
+        overwritten, and the method returns immediately. The backing file for
+        the profiles is automatically updated."""
 
         log.debug(">>> Add Profile '%s': %s" % (profile_name, attributes))
 
@@ -292,8 +294,10 @@ class Profile(UmitConfigParser, object):
         self.save_changes()
 
     def remove_profile(self, profile_name):
-        try: self.remove_section(profile_name)
-        except: pass
+        try:
+            self.remove_section(profile_name)
+        except:
+            pass
         self.save_changes()
 
     def _verify_profile(self, profile_name):
@@ -301,16 +305,17 @@ class Profile(UmitConfigParser, object):
             return False
         return True
 
+
 class CommandProfile (Profile, object):
     """This class is a wrapper around Profile that provides accessors for the
     attributes of a profile: command and description"""
-    def __init__(self, user_profile = None):
+    def __init__(self, user_profile=None):
         Profile.__init__(self, user_profile)
 
     def get_command(self, profile):
         command_string = self._get_it(profile, 'command')
-        # Old versions of Zenmap used to append "%s" to commands and use that to
-        # substitute the target. Ignore it if present.
+        # Old versions of Zenmap used to append "%s" to commands and use that
+        # to substitute the target. Ignore it if present.
         if command_string.endswith("%s"):
             command_string = command_string[:-len("%s")]
         return command_string
@@ -325,9 +330,9 @@ class CommandProfile (Profile, object):
         self._set_it(profile, 'description', description)
 
     def get_profile(self, profile_name):
-        return {'profile':profile_name, \
-                'command':self.get_command(profile_name), \
-                'description':self.get_description(profile_name)}
+        return {'profile': profile_name, \
+                'command': self.get_command(profile_name), \
+                'description': self.get_description(profile_name)}
 
 
 class NmapOutputHighlight(object):
@@ -381,10 +386,14 @@ class NmapOutputHighlight(object):
 
         tuple_regex = "[\(\[]\s?(\d+)\s?,\s?(\d+)\s?,\s?(\d+)\s?[\)\]]"
         if isinstance(settings[3], basestring):
-            settings[3] = [int(t) for t in re.findall(tuple_regex, settings[3])[0]]
+            settings[3] = [
+                    int(t) for t in re.findall(tuple_regex, settings[3])[0]
+                    ]
 
         if isinstance(settings[4], basestring):
-            settings[4]= [int(h) for h in re.findall(tuple_regex, settings[4])[0]]
+            settings[4] = [
+                    int(h) for h in re.findall(tuple_regex, settings[4])[0]
+                    ]
 
         return settings
 
@@ -446,17 +455,20 @@ class NmapOutputHighlight(object):
         try:
             enable = config_parser.get("output_highlight", "enable_highlight")
         except NoSectionError:
-            config_parser.set("output_highlight", "enable_highlight", str(True))
+            config_parser.set(
+                    "output_highlight", "enable_highlight", str(True))
 
         if enable == "False" or enable == "0" or enable == "":
             return False
         return True
 
     def set_enable(self, enable):
-        if enable == False or enable == "0" or enable == None or enable == "":
-            config_parser.set("output_highlight", "enable_highlight", str(False))
+        if enable == False or enable == "0" or enable is None or enable == "":
+            config_parser.set(
+                    "output_highlight", "enable_highlight", str(False))
         else:
-            config_parser.set("output_highlight", "enable_highlight", str(True))
+            config_parser.set(
+                    "output_highlight", "enable_highlight", str(True))
 
     date = property(get_date, set_date)
     hostname = property(get_hostname, set_hostname)
@@ -468,56 +480,68 @@ class NmapOutputHighlight(object):
     details = property(get_details, set_details)
     enable = property(get_enable, set_enable)
 
-    # These settings are made when there is nothing set yet. They set the "factory" \
-    # default to highlight colors
-    default_highlights = {"date":{"bold":str(True),
-                            "italic":str(False),
-                            "underline":str(False),
-                            "text":[0, 0, 0],
-                            "highlight":[65535, 65535, 65535],
-                            "regex":"\d{4}-\d{2}-\d{2}\s\d{2}:\d{2}\s.{1,4}"},
-                          "hostname":{"bold":str(True),
-                            "italic":str(True),
-                            "underline":str(True),
-                            "text":[0, 111, 65535],
-                            "highlight":[65535, 65535, 65535],
-                            "regex":"(\w{2,}://)*[\w-]{2,}\.[\w-]{2,}(\.[\w-]{2,})*(/[[\w-]{2,}]*)*"},
-                          "ip":{"bold":str(True),
-                            "italic":str(False),
-                            "underline":str(False),
-                            "text":[0, 0, 0],
-                            "highlight":[65535, 65535, 65535],
-                            "regex":"\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}"},
-                          "port_list":{"bold":str(True),
-                            "italic":str(False),
-                            "underline":str(False),
-                            "text":[0, 1272, 28362],
-                            "highlight":[65535, 65535, 65535],
-                            "regex":"PORT\s+STATE\s+SERVICE(\s+VERSION)?[^\n]*"},
-                          "open_port":{"bold":str(True),
-                            "italic":str(False),
-                            "underline":str(False),
-                            "text":[0, 41036, 2396],
-                            "highlight":[65535, 65535, 65535],
-                            "regex":"\d{1,5}/.{1,5}\s+open\s+.*"},
-                          "closed_port":{"bold":str(False),
-                            "italic":str(False),
-                            "underline":str(False),
-                            "text":[65535, 0, 0],
-                            "highlight":[65535, 65535, 65535],
-                            "regex":"\d{1,5}/.{1,5}\s+closed\s+.*"},
-                          "filtered_port":{"bold":str(False),
-                            "italic":str(False),
-                            "underline":str(False),
-                            "text":[38502, 39119, 0],
-                            "highlight":[65535, 65535, 65535],
-                            "regex":"\d{1,5}/.{1,5}\s+filtered\s+.*"},
-                          "details":{"bold":str(True),
-                            "italic":str(False),
-                            "underline":str(True),
-                            "text":[0, 0, 0],
-                            "highlight":[65535, 65535, 65535],
-                            "regex":"^(\w{2,}[\s]{,3}){,4}:"}}
+    # These settings are made when there is nothing set yet. They set the
+    # "factory" default to highlight colors
+    default_highlights = {
+            "date": {
+                "bold": str(True),
+                "italic": str(False),
+                "underline": str(False),
+                "text": [0, 0, 0],
+                "highlight": [65535, 65535, 65535],
+                "regex": "\d{4}-\d{2}-\d{2}\s\d{2}:\d{2}\s.{1,4}"},
+            "hostname": {
+                "bold": str(True),
+                "italic": str(True),
+                "underline": str(True),
+                "text": [0, 111, 65535],
+                "highlight": [65535, 65535, 65535],
+                "regex": "(\w{2,}://)*[\w-]{2,}\.[\w-]{2,}"
+                         "(\.[\w-]{2,})*(/[[\w-]{2,}]*)*"},
+            "ip": {
+                "bold": str(True),
+                "italic": str(False),
+                "underline": str(False),
+                "text": [0, 0, 0],
+                "highlight": [65535, 65535, 65535],
+                "regex": "\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}"},
+            "port_list": {
+                "bold": str(True),
+                "italic": str(False),
+                "underline": str(False),
+                "text": [0, 1272, 28362],
+                "highlight": [65535, 65535, 65535],
+                "regex": "PORT\s+STATE\s+SERVICE(\s+VERSION)?[^\n]*"},
+            "open_port": {
+                "bold": str(True),
+                "italic": str(False),
+                "underline": str(False),
+                "text": [0, 41036, 2396],
+                "highlight": [65535, 65535, 65535],
+                "regex": "\d{1,5}/.{1,5}\s+open\s+.*"},
+            "closed_port": {
+                "bold": str(False),
+                "italic": str(False),
+                "underline": str(False),
+                "text": [65535, 0, 0],
+                "highlight": [65535, 65535, 65535],
+                "regex": "\d{1,5}/.{1,5}\s+closed\s+.*"},
+            "filtered_port": {
+                "bold": str(False),
+                "italic": str(False),
+                "underline": str(False),
+                "text": [38502, 39119, 0],
+                "highlight": [65535, 65535, 65535],
+                "regex": "\d{1,5}/.{1,5}\s+filtered\s+.*"},
+            "details": {
+                "bold": str(True),
+                "italic": str(False),
+                "underline": str(True),
+                "text": [0, 0, 0],
+                "highlight": [65535, 65535, 65535],
+                "regex": "^(\w{2,}[\s]{,3}){,4}:"}
+            }
+
 
 # Retrieve details from zenmap.conf regarding paths subsection
 # (e.g. nmap_command_path) - jurand
@@ -530,8 +554,9 @@ class PathsConfig(object):
     def __get_it(self, p_name, default):
         try:
             return config_parser.get(self.section_name, p_name)
-        except (NoOptionError,NoSectionError):
-            log.debug(">>> Using default \"%s\" for \"%s\"." % (default, p_name))
+        except (NoOptionError, NoSectionError):
+            log.debug(
+                    ">>> Using default \"%s\" for \"%s\"." % (default, p_name))
             return default
 
     def __set_it(self, property_name, settings):
@@ -550,17 +575,22 @@ class PathsConfig(object):
         self.__set_it("ndiff_command_path", settings)
 
     nmap_command_path = property(get_nmap_command_path, set_nmap_command_path)
-    ndiff_command_path = property(get_ndiff_command_path, set_ndiff_command_path)
+    ndiff_command_path = property(
+            get_ndiff_command_path, set_ndiff_command_path)
+
 
 # Exceptions
 class ProfileNotFound:
-    def __init__ (self, profile):
+    def __init__(self, profile):
         self.profile = profile
-    def __str__ (self):
-        return "No profile named '"+self.profile+"' found!"
+
+    def __str__(self):
+        return "No profile named '" + self.profile + "' found!"
+
 
 class ProfileCouldNotBeSaved:
-    def __init__ (self, profile):
+    def __init__(self, profile):
         self.profile = profile
-    def __str__ (self):
-        return "Profile named '"+self.profile+"' could not be saved!"
+
+    def __str__(self):
+        return "Profile named '" + self.profile + "' could not be saved!"
